==> haskell-tasty-golden-2.3.5-380.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-golden
version:              2.3.5
visibility:           public
id:                   tasty-golden-2.3.5-DIuT53XX7oPKy0uZqUHe4J
key:                  tasty-golden-2.3.5-DIuT53XX7oPKy0uZqUHe4J
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/UnkindPartition/tasty-golden
synopsis:             Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.

category:             Testing
abi:                  81838f1f935e833da8a07f37c681e4e3
exposed:              True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage

hidden-modules:       Test.Tasty.Golden.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-golden-2.3.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-golden-2.3.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-golden-2.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-golden
hs-libraries:         HStasty-golden-2.3.5-DIuT53XX7oPKy0uZqUHe4J
depends:
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    optparse-applicative-0.18.1.0-AbA9pm273O8LTotNJ1t1CE
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    tasty-1.5.2-K3PchMZYxV2JdxeMIpuhjP
    temporary-1.3-DmygwHaZA8GJCfyTYb6Tkl text-2.0.2
    typed-process-0.2.13.0-EqZPeHIjk7UIrsbWZqASrc

haddock-interfaces:
    /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock

haddock-html:         /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-golden-2.3.5-383-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-golden
version:              2.3.5
visibility:           public
id:                   tasty-golden-2.3.5-3tjzWhZqOuJ7Oq5hS5ESPr
key:                  tasty-golden-2.3.5-3tjzWhZqOuJ7Oq5hS5ESPr
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/UnkindPartition/tasty-golden
synopsis:             Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.

category:             Testing
abi:                  f37f382aa3bc840c26e9de6af64d65d8
exposed:              True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage

hidden-modules:       Test.Tasty.Golden.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-golden-2.3.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-golden-2.3.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-golden-2.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-golden
hs-libraries:         HStasty-golden-2.3.5-3tjzWhZqOuJ7Oq5hS5ESPr
depends:
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    tasty-1.5.2-C3yI3pzTEHWEDVqwlNW4dB
    temporary-1.3-29RL4tTXoFB72QSCtJnhBC text-2.0.2
    typed-process-0.2.13.0-6gQ7sh9yVXJ5lWoFriePEE

haddock-interfaces:
    /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock

haddock-html:         /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
